Method: Pdfcrowd::HtmlToPdfClient#convertStringToStream
- Defined in:
- lib/pdfcrowd.rb
#convertStringToStream(text, out_stream) ⇒ Object
Convert a string and write the output to an output stream.
text- The string content to convert. The string must not be empty.out_stream- The output stream that will contain the conversion output.
867 868 869 870 871 872 873 874 |
# File 'lib/pdfcrowd.rb', line 867 def convertStringToStream(text, out_stream) if (!(!text.nil? && !text.empty?)) raise Error.new(Pdfcrowd.(text, "text", "html-to-pdf", "The string must not be empty.", "convert_string_to_stream"), 470); end @fields['text'] = text @helper.post(@fields, @files, @raw_data, out_stream) end |