Method: Pdfcrowd::HtmlToImageClient#convertStringToStream
- Defined in:
- lib/pdfcrowd.rb
#convertStringToStream(text, out_stream) ⇒ Object
Convert a string and write the output to an output stream.
-
text- The string content to convert. The string must not be empty. -
out_stream- The output stream that will contain the conversion output.
2045 2046 2047 2048 2049 2050 2051 2052 |
# File 'lib/pdfcrowd.rb', line 2045 def convertStringToStream(text, out_stream) if (!(!text.nil? && !text.empty?)) raise Error.new(Pdfcrowd.(text, "text", "html-to-image", "The string must not be empty.", "convert_string_to_stream"), 470); end @fields['text'] = text @helper.post(@fields, @files, @raw_data, out_stream) end |